# Changelog

All notable changes to this project will be documented in this file.

## [0.1.10] - 2025-05-03

### Added
- Changes in examples/templates/ansible/deploy.yml
- Changes in examples/templates/aws/cloudformation.yaml
- Changes in examples/templates/azure/template.json
- Changes in examples/templates/docker/Dockerfile
- Changes in examples/templates/docker/docker-compose.yml
- Changes in examples/templates/gcp/deployment.yaml
- Changes in examples/templates/github/workflow.yml
- Changes in examples/templates/gitlab/gitlab-ci.yml
- Changes in examples/templates/jenkins/Jenkinsfile
- Changes in examples/templates/kubernetes/deployment.yaml
- Changes in examples/templates/kubernetes/service.yaml
- Changes in examples/templates/terraform/main.tf
- Changes in examples/templates/terraform/variables.tf

### Changed
- Changes in examples/gitlab-ci.yml

## [0.1.9] - 2025-05-03

## [0.1.8] - 2025-05-03

### Added
- Changes in test_dependency_management.py

## [0.1.7] - 2025-05-03

### Added
- Changes in src/infrash/system/dependency_resolver.py
- Changes in test_dependency_resolver.py

## [0.1.6] - 2025-05-03

### Added
- Changes in examples/config.yaml
- Changes in examples/deploy.sh
- Changes in examples/diagnostics.json
- Changes in examples/gitlab-ci.yml
- Changes in src/infrash/core/diagnostics.py
- Changes in src/infrash/remote/__init__.py
- Changes in src/infrash/remote/remote_manager.py

## [0.1.5] - 2025-05-03

### Added
- Changes in examples/orchestrator/README.md
- Changes in examples/orchestrator/deploy_to_remote.py
- Changes in examples/orchestrator/run_nodejs_app.py
- Changes in examples/orchestrator/run_python_app.py
- Changes in src/unitmcp/__init__.py
- Changes in src/unitmcp/__main__.py
- Changes in src/unitmcp/cli.py
- Changes in src/unitmcp/orchestrator/__init__.py
- Changes in src/unitmcp/orchestrator/dependency_manager.py
- Changes in src/unitmcp/orchestrator/diagnostics.py
- Changes in src/unitmcp/orchestrator/network.py
- Changes in src/unitmcp/orchestrator/orchestrator.py
- Changes in src/unitmcp/orchestrator/project_detector.py
- Changes in tests/test_unitmcp_diagnostics.py
- Changes in tests/test_unitmcp_network.py
- Changes in tests/test_unitmcp_orchestrator.py

## [0.1.4] - 2025-05-03

### Added
- Changes in REMOTE.md
- Changes in gitrunner.py
- Changes in remote.py
- Changes in run.bat
- Changes in run.py
- Changes in run.sh
- Changes in src/infrash/core/diagnostics/configuration.py
- Changes in testpi.py

### Changed
- Changes in src/infrash/core/installer.py
- Changes in src/infrash/system/dependency.py
- Changes in src/infrash/system/service.py

### Fixed
- Changes in src/infrash/core/config.py

## [0.1.3] - 2025-05-03

### Added
- Changes in CONTRIBUTING.md
- Changes in environment.yml
- Changes in requirements-dev.txt
- Changes in src/infrash/core/diagnostics/__init__.py
- Changes in src/infrash/core/diagnostics/asyncio.py
- Changes in src/infrash/core/diagnostics/base.py
- Changes in src/infrash/core/diagnostics/connection.py
- Changes in src/infrash/core/diagnostics/database.py
- Changes in src/infrash/core/diagnostics/dependencies.py
- Changes in src/infrash/core/diagnostics/filesystem.py
- Changes in src/infrash/core/diagnostics/hardware.py
- Changes in src/infrash/core/diagnostics/logs.py
- Changes in src/infrash/core/diagnostics/networking.py
- Changes in src/infrash/core/diagnostics/process.py
- Changes in src/infrash/core/diagnostics/repository.py
- Changes in src/infrash/core/diagnostics/resources.py
- Changes in src/infrash/core/diagnostics/script.py
- Changes in src/infrash/core/os_detect/__init__.py
- Changes in src/infrash/core/os_detect/base.py
- Changes in src/infrash/core/os_detect/installation.py
- Changes in src/infrash/core/os_detect/package_manager.py
- Changes in src/infrash/core/os_detect/utilities.py
- Changes in src/infrash/core/repair/__init__.py
- Changes in src/infrash/core/repair/base.py
- Changes in src/infrash/core/repair/configuration.py
- Changes in src/infrash/core/repair/dependencies.py
- Changes in src/infrash/core/repair/execution.py
- Changes in src/infrash/core/repair/filesystem.py
- Changes in src/infrash/core/repair/permissions.py
- Changes in src/infrash/core/repair/solutions.py

### Removed
- Changes in src/infrash/core/diagnostics.py
- Changes in src/infrash/core/repair.py

## [0.1.2] - 2025-05-03

### Added
- Changes in .github/workflows/ci.yml
- Changes in .github/workflows/publish.yml
- Changes in docs/index.md
- Changes in docs/installation.md
- Changes in docs/troubleshooting.md
- Changes in docs/usage.md
- Changes in examples/advanced_configuration.py
- Changes in examples/basic_usage.py
- Changes in src.md
- Changes in src/infrash/__init__.py
- Changes in src/infrash/__main__.py
- Changes in src/infrash/cli.py
- Changes in src/infrash/core/__init__.py
- Changes in src/infrash/core/config.py
- Changes in src/infrash/core/diagnostics.py
- Changes in src/infrash/core/installer.py
- Changes in src/infrash/core/repair.py
- Changes in src/infrash/core/runner.py
- Changes in src/infrash/data/__init__.py
- Changes in src/infrash/data/solutions/__init__.py
- Changes in src/infrash/data/solutions/arch.json
- Changes in src/infrash/data/solutions/common.json
- Changes in src/infrash/data/solutions/debian.json
- Changes in src/infrash/data/solutions/redhat.json
- Changes in src/infrash/repo/__init__.py
- Changes in src/infrash/repo/clone.py
- Changes in src/infrash/repo/git.py
- Changes in src/infrash/repo/updater.py
- Changes in src/infrash/system/__init__.py
- Changes in src/infrash/system/dependency.py
- Changes in src/infrash/system/os_detect.py
- Changes in src/infrash/system/package_manager.py
- Changes in src/infrash/system/service.py
- Changes in src/infrash/utils/__init__.py
- Changes in src/infrash/utils/ai_solver.py
- Changes in src/infrash/utils/database.py
- Changes in src/infrash/utils/logger.py
- Changes in src/infrash/utils/network.py
- Changes in tests/__init__.py
- Changes in tests/test_diagnostics.py
- Changes in tests/test_installer.py
- Changes in tests/test_repo.py
- Changes in tests/test_runner.py

## [0.1.1] - 2025-05-03

### Added
- Changes in Gemfile
- Changes in MANIFEST.in
- Changes in Makefile
- Changes in TODO.md
- Changes in TODO.txt
- Changes in _config.yml
- Changes in mermaid.js
- Changes in pyproject.toml
- Changes in requirements.txt
- Changes in run_tests.py
- Changes in setup.cfg
- Changes in setup.py
- Changes in tools/clean_fedora.sh
- Changes in tools/detailed_tests.py
- Changes in tools/fix_implementation.py
- Changes in tools/fix_source_files.py
- Changes in tools/hardware/README.md
- Changes in tools/hardware/configure_hardware.ps1
- Changes in tools/hardware/configure_hardware.sh
- Changes in tools/install/README.md
- Changes in tools/install/SPACY.md
- Changes in tools/install/install.sh
- Changes in tools/install/install_models.sh
- Changes in tools/install/install_tkinter.ps1
- Changes in tools/install/install_tkinter.sh
- Changes in tools/install/install_windows.ps1
- Changes in tools/install/pyaudio.py
- Changes in tools/install/pyaudio2.py
- Changes in tools/install/pyaudiodiag.py
- Changes in tools/install/pyautogui.md
- Changes in tools/install/pyautogui.py
- Changes in tools/install/python312.sh
- Changes in tools/install/shared_install.sh
- Changes in tools/install/windows.ps1
- Changes in tools/macos/README.md
- Changes in tools/macos/install.sh
- Changes in tools/misc/README.md
- Changes in tools/misc/README_ssh_tools.md
- Changes in tools/nlp/README.md
- Changes in tools/nlp/spacy.sh
- Changes in tools/python/README.md
- Changes in tools/python/pip.sh
- Changes in tools/python/python.sh
- Changes in tools/python/requirements.sh
- Changes in tools/restart_docker.sh
- Changes in tools/rpi/README.md
- Changes in tools/rpi/fix_cert.sh
- Changes in tools/rpi/optimize_rpi.sh
- Changes in tools/rpi/update.sh
- Changes in tools/run_all_examples.sh
- Changes in tools/run_enhanced_hardware.sh
- Changes in tools/run_example.sh
- Changes in tools/run_hardware_with_server.sh
- Changes in tools/run_speaker_with_server.sh
- Changes in tools/run_tests.py
- Changes in tools/runner/__init__.py
- Changes in tools/runner/claude_interface.py
- Changes in tools/runner/client_setup.py
- Changes in tools/runner/llm_interface.py
- Changes in tools/runner/main.py
- Changes in tools/runner/ollama_interface.py
- Changes in tools/runner/rpi_server_starter.py
- Changes in tools/runner/server_setup.py
- Changes in tools/server_diagnostics.py
- Changes in tools/setup_service.sh
- Changes in tools/ssh/README.md
- Changes in tools/ssh/README_ssh_tools.md
- Changes in tools/ssh/remote_update.sh
- Changes in tools/ssh/ssh.sh
- Changes in tools/ssh/ssh_connect.py
- Changes in tools/ssh/ssh_connect_wrapper.sh
- Changes in tools/start.sh
- Changes in tools/start_mcp_server.sh
- Changes in tools/start_rpi_server.py
- Changes in tools/start_service.sh
- Changes in tools/start_updated_rpi_server.py
- Changes in tools/test/README.md
- Changes in tools/test/debug_imports.py
- Changes in tools/test/env.sh
- Changes in tools/test/test_imports.py
- Changes in tools/test_env_loader_fix.py
- Changes in tools/test_infrash_integration.py
- Changes in tools/update/README.md
- Changes in tools/update/changelog.py
- Changes in tools/update/code.sh
- Changes in tools/update/duplicated.py
- Changes in tools/update/duplicated.sh
- Changes in tools/update/git.sh
- Changes in tools/update/package.sh
- Changes in tools/update/pypi.sh
- Changes in tools/update/requirements.py
- Changes in tools/update/src.py
- Changes in tools/update/upgrade.sh
- Changes in tools/update/version.sh
- Changes in tools/update/versions.py
- Changes in tools/update_rpi_repo.py
- Changes in tools/verify_migration.py
- Changes in tox.ini
- Changes in update/1versions.py
- Changes in update/README.md
- Changes in update/changelog.py
- Changes in update/code.sh
- Changes in update/duplicated.py
- Changes in update/duplicated.sh
- Changes in update/git.sh
- Changes in update/package.sh
- Changes in update/pypi.sh
- Changes in update/requirements.py
- Changes in update/src.py
- Changes in update/upgrade.sh
- Changes in update/version.sh

### Changed
- Changes in .gitignore
- Changes in LICENSE

